(function () {
  // → Einfaches Toast-Feedback in Oxygen-UI
  function showOxyToast(message, duration = 3000) {
    const parentDoc = window.parent.document;
    let toast = parentDoc.getElementById('oxy-custom-toast');
    if (!toast) {
      toast = parentDoc.createElement('div');
      toast.id = 'oxy-custom-toast';
      toast.style.cssText = `
        position: fixed; top: 20px; right: 20px; z-index: 999999;
        padding: 12px 16px; background-color: #323232; color: white;
        border-radius: 6px; font-size: 14px;
        box-shadow: 0 4px 10px rgba(0, 0, 0, 0.2);
        opacity: 0; transform: translateY(-10px);
        transition: opacity 0.3s ease, transform 0.3s ease;
        pointer-events: none !important;
      `;
      parentDoc.body.appendChild(toast);
    }
    toast.textContent = message;
    toast.style.opacity = '1';
    toast.style.transform = 'translateY(0)';
    setTimeout(() => {
      toast.style.opacity = '0';
      toast.style.transform = 'translateY(-10px)';
    }, duration);
  }

  // → Oxygen-Vuex-Store aus dem Parent-Iframe
  function getParentVueStore() {
    const el = window.parent.document.querySelector('.v-application');
    return el?.__vue__?.$store
      || el?.__vue_app__?.config?.globalProperties?.$store
      || null;
  }

  const store = getParentVueStore();
  window.__oxyStore = store;

  // Hilfsfunktion: Element-Type in lesbaren Slug umwandeln
  function getTypeSlug(type) {
    const parts = type.split('\\');
    return (parts.pop() || type).toLowerCase();
  }
  
  // Hilfsfunktion: Prüft ob eine Eigenschaft zum Grid gehört
  function isGridProperty(key, props) {
    return key.startsWith('grid') || 
           key === 'grid-column-count' || 
           (props.display === 'grid' && (key === 'column-gap' || key === 'row-gap'));
  }

  document.addEventListener('paste', async (event) => {
    if (window.__oxyIsAutoPaste) {
      window.__oxyIsAutoPaste = false;
      return;
    }

    const txt = (event.clipboardData || window.clipboardData).getData('text');
    let parsed;
    try { parsed = JSON.parse(txt); } catch { return; }
    if (!parsed.element || !Array.isArray(parsed.classes)) return;

    event.preventDefault();
    event.stopImmediatePropagation();

    // --- Prepare class mappings ---
    const oldToName = new Map(parsed.classes.map(c => [c.id, c.name]));
    const oxy = store.state.global.oxySelectors || [];
    const nameToNewId = new Map(oxy.map(c => [c.name, c.id]));

    // --- Generate generic classes for inline props with de-duplication ---
    const inlineClasses = [];
    const typeCounters = {};
    function extractInline(el) {
      const props = el.data?.properties || {};
      const meta = props.meta;
      const content = props.content;
      
      // Check for grid properties specially
      let hasGridProps = false;
      if (props.grid && props.grid.enable) {
        // Grid properties are already organized - don't break them apart
        hasGridProps = true;
      }
      
      const inlineKeys = Object.keys(props).filter(k => 
        !['meta', 'content'].includes(k) && 
        // Keep grid as a unified property if it exists
        !(hasGridProps && k === 'grid')
      );
      if (inlineKeys.length) {
        const slug = getTypeSlug(el.data.type);
        let count = (typeCounters[slug] = (typeCounters[slug] || 0) + 1);
        let className = 'lvl-' + slug + count;
        while (nameToNewId.has(className)) {
          count++;
          className = 'lvl-' + slug + count;
        }
        // Check for existing class with identical props
        const allExisting = [...oxy, ...inlineClasses];
        const match = allExisting.find(c => {
          try {
            return JSON.stringify(c.properties) === JSON.stringify(props);
          } catch {
            return false;
          }
        });
        let classId, finalName;
        if (match) {
          classId = match.id;
          finalName = match.name;
          console.log('🔍 Reusing class', finalName, '(', classId, ') for identical props');
        } else {
          classId = crypto.randomUUID();
          finalName = className;
          const classObj = {
            id: classId,
            name: finalName,
            properties: { ...props },
            children: [], locked: false,
            collection: 'Default', type: 'class'
          };
          inlineClasses.push(classObj);
          console.log('🔧 Created generic class:', finalName, '(', classId, ') with properties:', classObj.properties);
        }
        nameToNewId.set(finalName, classId);
        props.meta = {
          classes: [
            ...(meta?.classes || []).map(old => nameToNewId.get(oldToName.get(old)) || old),
            classId
          ]
        };
        props.content = content;
        inlineKeys.forEach(k => delete props[k]);
      }
      (el.children || []).forEach(extractInline);
    }
    extractInline(parsed.element);

    // --- Add missing JSON classes ---
    const toCreate = parsed.classes
      .filter(c => !nameToNewId.has(c.name))
      .map(c => ({
        id: crypto.randomUUID(), name: c.name,
        properties: c.properties || {}, children: [], locked: false,
        collection: 'Default', type: 'class'
      }));

    // Commit all new classes
    const allNew = [...inlineClasses, ...toCreate];
    if (allNew.length) {
      store.commit('global/setOxygenSelectors', [...oxy, ...allNew]);
      store.state.global.oxySelectors.forEach(c => nameToNewId.set(c.name, c.id));
    }

    // --- Remap element classes ---
    (function remap(el) {
      const clsArr = el.data?.properties?.meta?.classes;
      if (Array.isArray(clsArr)) {
        el.data.properties.meta.classes = clsArr.map(old =>
          nameToNewId.get(oldToName.get(old)) || old
        );
      }
      (el.children || []).forEach(remap);
    })(parsed.element);

    // Dispatch modified paste
    showOxyToast('✅ Klassen importiert');
    const dt = new DataTransfer();
    dt.setData('text', JSON.stringify(parsed));
    const pe = new ClipboardEvent('paste', { clipboardData: dt, bubbles: true, cancelable: true });
    window.__oxyIsAutoPaste = true;
    document.dispatchEvent(pe);
  });
})();
